==> devextreme-20.2.12.tgz: package/renovation/ui/scheduler/workspaces/base/date_table/all_day_panel/title.j.js <==
/**
 * DevExtreme (renovation/ui/scheduler/workspaces/base/date_table/all_day_panel/title.j.js)
 * Version: 20.2.12
 * Build date: Tue Oct 18 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.default = void 0;
var _component_registrator = _interopRequireDefault(require("../../../../../../../core/component_registrator"));
var _component = _interopRequireDefault(require("../../../../../../preact_wrapper/component"));
var _title = require("./title");

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        "default": obj
    }
}

function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) {
            descriptor.writable = true
        }
        Object.defineProperty(target, descriptor.key, descriptor)
    }
}

function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) {
        _defineProperties(Constructor.prototype, protoProps)
    }
    if (staticProps) {
        _defineProperties(Constructor, staticProps)
    }
    Object.defineProperty(Constructor, "prototype", {
        writable: false
    });
    return Constructor
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var AllDayPanelTitle = function(_BaseComponent) {
    _inheritsLoose(AllDayPanelTitle, _BaseComponent);

    function AllDayPanelTitle() {
        return _BaseComponent.apply(this, arguments) || this
    }
    _createClass(AllDayPanelTitle, [{
        key: "_propsInfo",
        get: function() {
            return {
                twoWay: [],
                allowNull: [],
                elements: []
            }
        }
    }, {
        key: "_viewComponent",
        get: function() {
            return _title.AllDayPanelTitle
        }
    }]);
    return AllDayPanelTitle
}(_component.default);
exports.default = AllDayPanelTitle;
(0, _component_registrator.default)("dxAllDayPanelTitle", AllDayPanelTitle);
module.exports = exports.default;

==> devextreme-21.1.4.tgz: package/renovation/ui/scheduler/workspaces/base/date_table/all_day_panel/title.j.js <==
/**
 * DevExtreme (renovation/ui/scheduler/workspaces/base/date_table/all_day_panel/title.j.js)
 * Version: 21.1.4
 * Build date: Mon Jun 21 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.default = void 0;
var _component_registrator = _interopRequireDefault(require("../../../../../../../core/component_registrator"));
var _component = _interopRequireDefault(require("../../../../../../component_wrapper/component"));
var _title = require("./title");

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) {
            descriptor.writable = true
        }
        Object.defineProperty(target, descriptor.key, descriptor)
    }
}

function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) {
        _defineProperties(Constructor.prototype, protoProps)
    }
    if (staticProps) {
        _defineProperties(Constructor, staticProps)
    }
    return Constructor
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var AllDayPanelTitle = function(_BaseComponent) {
    _inheritsLoose(AllDayPanelTitle, _BaseComponent);

    function AllDayPanelTitle() {
        return _BaseComponent.apply(this, arguments) || this
    }
    _createClass(AllDayPanelTitle, [{
        key: "_propsInfo",
        get: function() {
            return {
                twoWay: [],
                allowNull: [],
                elements: [],
                templates: [],
                props: ["className", "visible"]
            }
        }
    }, {
        key: "_viewComponent",
        get: function() {
            return _title.AllDayPanelTitle
        }
    }]);
    return AllDayPanelTitle
}(_component.default);
exports.default = AllDayPanelTitle;
(0, _component_registrator.default)("dxAllDayPanelTitle", AllDayPanelTitle);
module.exports = exports.default;
module.exports.default = exports.default;
